/***************************************************************************
 *   Copyright (C) 2004-2007 by Georgy Yunaev, gyunaev@ulduzsoft.com       *
 *   Please do not use email address above for bug reports; see            *
 *   the README file                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef KCHMDIALOGCHOOSEURLFROMLIST_H
#define KCHMDIALOGCHOOSEURLFROMLIST_H

#include <tqdialog.h>
#include <tqlistview.h>

/**
@author tim
*/
class KCHMDialogChooseUrlFromList : public TQDialog
{
TQ_OBJECT
  
public:
    KCHMDialogChooseUrlFromList (const TQStringList& urls, const TQStringList& titles, TQWidget* parent);
	TQString getSelectedItemUrl()	{ return m_acceptedurl; }

private slots:
	void onDoubleClicked( TQListViewItem * item, const TQPoint &, int );
	void onCurrentChanged ( TQListViewItem * item);

private:
	TQListView *	m_urlsList;
	TQString		m_acceptedurl;
};

#endif
